@@ -12,7 +12,6 @@
 // If not, see <https://opensource.org/licenses/MIT>.
 
 use std::any::Any;
-use std::borrow::Borrow;
 use std::collections::BTreeMap;
 use std::io;
 use std::io::{Read, Write};
@@ -202,10 +201,9 @@ impl lightning_encoding::LightningDecode for Stream {
         // Reading stream record by record until it is over
         while let Some(ty) = Type::lightning_decode(&mut d)
             .map(Option::Some)
-            .or_else(|err| match &err {
-                lightning_encoding::Error::BigSizeNotCanonical
-                | lightning_encoding::Error::BigSizeEof => Err(err),
-                _ => Ok(None),
+            .or_else(|err| match err {
+                lightning_encoding::Error::BigSizeNoValue => Ok(None),
+                err => Err(err),
             })?
         {
             let val = RawValue::lightning_decode(&mut d)?;
@@ -227,20 +225,22 @@ impl lightning_encoding::LightningDecode for Stream {
     }
 }
 
+// This structure is not used anywhere and should be removed
+#[deprecated(
+    since = "0.6.0",
+    note = "use Stream::lightning_decode and process the data afterwards"
+)]
 pub struct Unmarshaller {
     known_types: BTreeMap<Type, UnmarshallFn<Error>>,
     raw_parser: UnmarshallFn<Error>,
 }
 
+#[allow(deprecated)]
 impl Unmarshall for Unmarshaller {
     type Data = Stream;
     type Error = Error;
 
-    fn unmarshall(
-        &self,
-        data: &dyn Borrow<[u8]>,
-    ) -> Result<Stream, Self::Error> {
-        let mut reader = io::Cursor::new(data.borrow());
+    fn unmarshall(&self, mut reader: impl Read) -> Result<Stream, Self::Error> {
         let mut tlv = Stream::new();
         let mut prev_type_id = Type(0);
         loop {
@@ -312,6 +312,7 @@ impl Unmarshall for Unmarshaller {
     }
 }
 
+#[allow(deprecated)]
 impl Unmarshaller {
     pub fn new() -> Self {
         Self {
@@ -348,6 +349,7 @@ impl Unmarshaller {
     }
 }
 
+#[allow(deprecated)]
 impl Default for Unmarshaller {
     fn default() -> Self { Unmarshaller::new() }
 }
