@@ -212,10 +212,7 @@ fn recv_brontide_message(
 impl Session for Raw<NoiseTranscoder, brontide::Connection> {
     fn recv_raw_message(&mut self) -> Result<Vec<u8>, Error> {
         let reader = self.connection.as_receiver();
-        Ok(recv_brontide_message(
-            reader,
-            &mut self.transcoder.decryptor,
-        )?)
+        recv_brontide_message(reader, &mut self.transcoder.decryptor)
     }
 
     #[inline]
@@ -437,7 +434,10 @@ where
 {
     pub fn as_socket(&self) -> &zmq::Socket { self.connection.as_socket() }
 
-    pub fn set_identity(&mut self, identity: &[u8]) -> Result<(), Error> {
+    pub fn set_identity(
+        &mut self,
+        identity: &impl AsRef<[u8]>,
+    ) -> Result<(), Error> {
         self.connection.set_identity(identity).map_err(Error::from)
     }
 }
@@ -478,7 +478,7 @@ impl Input for RawInput<PlainTranscoder, ftcp::Stream> {
 impl Input for RawInput<NoiseDecryptor, brontide::Stream> {
     #[inline]
     fn recv_raw_message(&mut self) -> Result<Vec<u8>, Error> {
-        Ok(recv_brontide_message(&mut self.input, &mut self.decryptor)?)
+        recv_brontide_message(&mut self.input, &mut self.decryptor)
     }
     fn recv_routed_message(&mut self) -> Result<RoutedFrame, Error> {
         InternalInput::recv_routed_message(self)
