@@ -24,11 +24,11 @@ fn receiver(local_node: &LocalNode, node: RemoteNodeAddr) {
     let mut session = node.accept(local_node).unwrap();
     let msg = session.recv_raw_message().unwrap();
     assert_eq!(msg, b"Hello world");
-    //std::thread::sleep(core::time::Duration::from_secs(3));
+    std::thread::sleep(core::time::Duration::from_secs(3));
 }
 
 fn sender(local_node: &LocalNode, node: RemoteNodeAddr) {
-    //std::thread::sleep(core::time::Duration::from_secs(1));
+    std::thread::sleep(core::time::Duration::from_secs(1));
     let mut session = node.connect(local_node).unwrap();
     session.send_raw_message(b"Hello world").unwrap();
 }
